==> modonomicon-1.21.5-fabric-1.117.2-sources.jar: com/klikli_dev/modonomicon/client/gui/book/markdown/BookTextRenderer.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.client.gui.book.markdown;

import com.klikli_dev.modonomicon.book.Book;
import com.klikli_dev.modonomicon.client.gui.book.markdown.ext.ComponentStrikethroughExtension;
import com.klikli_dev.modonomicon.client.gui.book.markdown.ext.ComponentUnderlineExtension;
import com.klikli_dev.modonomicon.data.BookDataManager;
import org.commonmark.Extension;
import org.commonmark.parser.Parser;

import java.util.List;
import net.minecraft.class_2583;
import net.minecraft.class_5250;
import net.minecraft.class_5251;
import net.minecraft.class_7225;

public class BookTextRenderer {

    private final Parser markdownParser;

    private final List<Extension> extensions;

    private final Book book;

    private final class_7225.class_7874 provider;

    public BookTextRenderer(Book book, class_7225.class_7874 provider) {
        //TODO: make parser configurable for modders
        this.extensions = List.of(ComponentStrikethroughExtension.create(), ComponentUnderlineExtension.create());
        this.markdownParser = Parser.builder()
                .extensions(this.extensions)
                .build();
        this.book = book;
        this.provider = provider;
    }

    public List<class_5250> render(String markdown) {
        return this.render(markdown, class_2583.field_24360);
    }

    public List<class_5250> render(String markdown, class_2583 defaultStyle) {
        //TODO: make renderer configurable for modders

        //renderer needs to be instantiated every time, because it caches the results
        var renderer = new ComponentRenderer.Builder()
                .renderSoftLineBreaks(false)
                .replaceSoftLineBreaksWithSpace(true)
                .linkColor(class_5251.method_27717(0x5555FF))
                .linkRenderers(List.of(
                        new ColorLinkRenderer(),
                        new BookLinkRenderer(),
                        new ItemLinkRenderer(),
                        new PatchouliLinkRenderer(),
                        new DynamicMacroLinkRenderer(),
                        new CommandLinkRenderer()))
                .style(defaultStyle.method_27704(BookDataManager.Client.get().safeFont(this.book.getFont())))
                .extensions(this.extensions)
                .build();

        var document = this.markdownParser.parse(markdown);

        return renderer.render(document, this.book, this.provider);
    }
}

==> modonomicon-1.21.8-fabric-1.116.0-sources.jar: com/klikli_dev/modonomicon/client/gui/book/markdown/BookTextRenderer.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.client.gui.book.markdown;

import com.klikli_dev.modonomicon.book.Book;
import com.klikli_dev.modonomicon.client.gui.book.markdown.ext.ComponentStrikethroughExtension;
import com.klikli_dev.modonomicon.client.gui.book.markdown.ext.ComponentUnderlineExtension;
import com.klikli_dev.modonomicon.data.BookDataManager;
import org.commonmark.Extension;
import org.commonmark.parser.Parser;

import java.util.List;
import net.minecraft.class_124;
import net.minecraft.class_2583;
import net.minecraft.class_5250;
import net.minecraft.class_5251;
import net.minecraft.class_7225;

public class BookTextRenderer {

    private final Parser markdownParser;

    private final List<Extension> extensions;

    private final Book book;

    private final class_7225.class_7874 provider;

    public BookTextRenderer(Book book, class_7225.class_7874 provider) {
        //TODO: make parser configurable for modders
        this.extensions = List.of(ComponentStrikethroughExtension.create(), ComponentUnderlineExtension.create());
        this.markdownParser = Parser.builder()
                .extensions(this.extensions)
                .build();
        this.book = book;
        this.provider = provider;
    }

    public List<class_5250> render(String markdown) {
        return this.render(markdown, class_2583.field_24360.method_10977(class_124.field_1074));
    }

    public List<class_5250> render(String markdown, class_2583 defaultStyle) {
        //TODO: make renderer configurable for modders

        //renderer needs to be instantiated every time, because it caches the results
        var renderer = new ComponentRenderer.Builder()
                .renderSoftLineBreaks(false)
                .replaceSoftLineBreaksWithSpace(true)
                .linkColor(class_5251.method_27717(0x5555FF))
                .linkRenderers(List.of(
                        new ColorLinkRenderer(),
                        new BookLinkRenderer(),
                        new ItemLinkRenderer(),
                        new PatchouliLinkRenderer(),
                        new DynamicMacroLinkRenderer(),
                        new CommandLinkRenderer()))
                .style(defaultStyle.method_27704(BookDataManager.Client.get().safeFont(this.book.getFont())))
                .extensions(this.extensions)
                .build();

        var document = this.markdownParser.parse(markdown);

        return renderer.render(document, this.book, this.provider);
    }
}
